@@ -23,6 +23,8 @@
 #pragma warning(pop)
 #endif
 
+#include <google/protobuf/text_format.h>
+
 #include <chrono>
 #include <cstring>
 #include <iostream>
@@ -43,15 +45,15 @@
 #pragma warning(pop)
 #endif
 
-#include "ignition/transport/AdvertiseOptions.hh"
-#include "ignition/transport/Discovery.hh"
-#include "ignition/transport/Helpers.hh"
-#include "ignition/transport/NodeShared.hh"
-#include "ignition/transport/RepHandler.hh"
-#include "ignition/transport/ReqHandler.hh"
-#include "ignition/transport/SubscriptionHandler.hh"
-#include "ignition/transport/TransportTypes.hh"
-#include "ignition/transport/Uuid.hh"
+#include "gz/transport/AdvertiseOptions.hh"
+#include "gz/transport/Discovery.hh"
+#include "gz/transport/Helpers.hh"
+#include "gz/transport/NodeShared.hh"
+#include "gz/transport/RepHandler.hh"
+#include "gz/transport/ReqHandler.hh"
+#include "gz/transport/SubscriptionHandler.hh"
+#include "gz/transport/TransportTypes.hh"
+#include "gz/transport/Uuid.hh"
 
 #include "NodeSharedPrivate.hh"
 
@@ -60,8 +62,6 @@
 #endif
 
 using namespace std::chrono_literals;
-using namespace ignition;
-using namespace transport;
 
 const char kIgnAuthDomain[] = "ign-auth";
 
@@ -167,6 +167,8 @@ void sendAuthErrorHelper(zmq::socket_t &_socket, const std::string &_err)
 #endif
 }
 
+namespace ignition::transport
+{
 //////////////////////////////////////////////////
 NodeShared *NodeShared::Instance()
 {
@@ -755,7 +757,7 @@ void NodeShared::RecvSrvRequest()
 
     // If 'reptype' is msgs::Empty", this is a oneway request
     // and we don't send response
-    if (repType == ignition::msgs::Empty().GetTypeName())
+    if (repType == msgs::Empty().GetTypeName())
     {
       return;
     }
@@ -1124,7 +1126,7 @@ void NodeShared::SendPendingRemoteReqs(const std::string &_topic,
 
       // Remove the handler associated to this service request. We won't
       // receive a response because this is a oneway request.
-      if (_repType == ignition::msgs::Empty().GetTypeName())
+      if (_repType == msgs::Empty().GetTypeName())
       {
         this->requests.RemoveHandler(_topic, nodeUuid, reqUuid);
       }
@@ -1319,7 +1321,7 @@ void NodeShared::OnNewRegistration(const MessagePublisher &_pub)
 void NodeShared::OnEndRegistration(const MessagePublisher &_pub)
 {
   // Discard the message if the destination PUUID is not me.
-  if (_pub.Ctrl() != this->pUuid)
+  if (!_pub.Ctrl().empty() && _pub.Ctrl() != this->pUuid)
     return;
 
   std::string topic = _pub.Topic();
@@ -1824,9 +1826,20 @@ void NodeSharedPrivate::PublishThread()
       }
       catch (...)
       {
-        std::cerr << "Exception occurred in a local callback "
+        if (std::string str;
+            google::protobuf::TextFormat::PrintToString(
+              *(msgDetails->msgCopy), &str))
+        {
+          std::cerr << "Exception occurred in a local callback "
           << "on topic [" << msgDetails->info.Topic() << "] with message ["
-          << msgDetails->msgCopy->DebugString() << "]" << std::endl;
+          << str << "]" << std::endl;
+        }
+        else
+        {
+          std::cerr << "Exception occurred in a local callback "
+          << "on topic [" << msgDetails->info.Topic() << "]. Unable to show msg"
+          << std::endl;
+        }
       }
     }
 
@@ -1840,17 +1853,27 @@ void NodeSharedPrivate::PublishThread()
       }
       catch (...)
       {
-        std::cerr << "Exception occured in a local raw callback "
-          << "on topic [" << msgDetails->info.Topic() << "] with "
-          << "message [" << msgDetails->msgCopy->DebugString() << "]"
+        if (std::string str;
+            google::protobuf::TextFormat::PrintToString(
+              *(msgDetails->msgCopy), &str))
+        {
+          std::cerr << "Exception occurred in a local raw callback "
+          << "on topic [" << msgDetails->info.Topic() << "] with message ["
+          << str << "]" << std::endl;
+        }
+        else
+        {
+          std::cerr << "Exception occurred in a local raw callback "
+          << "on topic [" << msgDetails->info.Topic() << "]. Unable to show msg"
           << std::endl;
+        }
       }
     }
   }
 }
 
 //////////////////////////////////////////////////
-std::optional<transport::TopicStatistics> NodeShared::TopicStats(
+std::optional<TopicStatistics> NodeShared::TopicStats(
     const std::string &_topic) const
 {
   if (this->dataPtr->topicStats.find(_topic) != this->dataPtr->topicStats.end())
@@ -1868,7 +1891,7 @@ void NodeShared::EnableStats(const std::string &_topic, bool _enable,
   }
   else
   {
-    this->dataPtr->enabledTopicStatistics.extract(_topic);
+    this->dataPtr->enabledTopicStatistics.erase(_topic);
     // \todo Also cleanup topicStats.
   }
 }
@@ -1909,3 +1932,4 @@ int NodeSharedPrivate::NonNegativeEnvVar(const std::string &_envVar,
   }
   return numVal;
 }
+}  // namespace ignition::transport
