@@ -20,15 +20,14 @@
 #include <iostream>
 #include <string>
 
-#include "ignition/transport/AdvertiseOptions.hh"
-#include "ignition/transport/Helpers.hh"
-#include "ignition/transport/Publisher.hh"
-#include "ignition/transport/NodeShared.hh"
-#include "ignition/transport/SubscriptionHandler.hh"
-
-using namespace ignition;
-using namespace transport;
+#include "gz/transport/AdvertiseOptions.hh"
+#include "gz/transport/Helpers.hh"
+#include "gz/transport/Publisher.hh"
+#include "gz/transport/NodeShared.hh"
+#include "gz/transport/SubscriptionHandler.hh"
 
+namespace ignition::transport
+{
 //////////////////////////////////////////////////
 Publisher::Publisher(const std::string &_topic, const std::string &_addr,
   const std::string &_pUuid, const std::string &_nUuid,
@@ -41,9 +40,6 @@ Publisher::Publisher(const std::string &_topic, const std::string &_addr,
 {
 }
 
-//////////////////////////////////////////////////
-Publisher::Publisher(const Publisher &_other) = default;
-
 //////////////////////////////////////////////////
 std::string Publisher::Topic() const
 {
@@ -165,9 +161,6 @@ bool Publisher::operator!=(const Publisher &_pub) const
   return !(*this == _pub);
 }
 
-//////////////////////////////////////////////////
-Publisher &Publisher::operator=(const Publisher &_other) = default;
-
 //////////////////////////////////////////////////
 MessagePublisher::MessagePublisher(const std::string &_topic,
   const std::string &_addr, const std::string &_ctrl, const std::string &_pUuid,
@@ -180,9 +173,6 @@ MessagePublisher::MessagePublisher(const std::string &_topic,
 {
 }
 
-//////////////////////////////////////////////////
-MessagePublisher::MessagePublisher(const MessagePublisher &_other) = default;
-
 //////////////////////////////////////////////////
 std::string MessagePublisher::Ctrl() const
 {
@@ -259,10 +249,6 @@ bool MessagePublisher::operator!=(const MessagePublisher &_pub) const
   return !(*this == _pub);
 }
 
-//////////////////////////////////////////////////
-MessagePublisher &MessagePublisher::operator=(const MessagePublisher &_other)
-  = default;
-
 //////////////////////////////////////////////////
 ServicePublisher::ServicePublisher(const std::string &_topic,
   const std::string &_addr, const std::string &_socketId,
@@ -277,8 +263,6 @@ ServicePublisher::ServicePublisher(const std::string &_topic,
 {
 }
 
-//////////////////////////////////////////////////
-ServicePublisher::ServicePublisher(const ServicePublisher &_other) = default;
 
 //////////////////////////////////////////////////
 std::string ServicePublisher::SocketId() const
@@ -364,7 +348,4 @@ bool ServicePublisher::operator!=(const ServicePublisher &_srv) const
 {
   return !(*this == _srv);
 }
-
-//////////////////////////////////////////////////
-ServicePublisher &ServicePublisher::operator=(const ServicePublisher &_other)
-  = default;
+}  // namespace ignition::transport
