@@ -48,8 +48,6 @@ GZ_RECORD_COMPLETION_LIST="
   --pattern
 "
 
-# TODO: In Fortress+, remove --force-version and --versions. Add --help-all.
-# Update ../gz_TEST.cc accordingly.
 GZ_SERVICE_COMPLETION_LIST="
   -h --help
   -v --version
@@ -60,13 +58,11 @@ GZ_SERVICE_COMPLETION_LIST="
   -l --list
   -i --info
   -r --req
-  --force-version
-  --versions
+  --help-all
 "
 
 GZ_TOPIC_COMPLETION_LIST="
   -h --help
-  -v --version
   -t --topic
   -m --msgtype
   -d --duration
@@ -75,8 +71,8 @@ GZ_TOPIC_COMPLETION_LIST="
   -i --info
   -e --echo
   -p --pub
-  --force-version
-  --versions
+  -v --version
+  --json-output
 "
 
 function __get_comp_from_list {
